Changelog
=========

Version 0.0.8
-------------

:Date: June 02, 2020

* Fix check_org_on_whitelist function


Version 0.0.7
-------------

:Date: May 31, 2020

* Ignore private ip addresses
* Add external script execution when an anomaly is found


Version 0.0.6
-------------

:Date: May 25, 2020

* Fix email report


Version 0.0.5
-------------

:Date: May 25, 2020

* Add option to send report by Mattermost


Version 0.0.4
-------------

:Date: May 24, 2020

* Add Sphinx documentation
* Add tests to sdist


Version 0.0.3
-------------

:Date: May 24, 2020

* Initial release